macro_rules! main_dll {
($func:expr) => { ... };
}Expand description
Macro that creates the MainDLL function. This function has a special signature that needed by WinAPI to create a DLL.
macro_rules! main_dll {
($func:expr) => { ... };
}Macro that creates the MainDLL function. This function has a special signature that needed by WinAPI to create a DLL.